OC.L10N.register(
    "core",
    {
    "Please select a file." : "Izberite datoteko.",
    "File is too big" : "Datoteka je prevelika",
    "The selected file is not an image." : "Izbrana datoteka ni slika.",
    "The selected file cannot be read." : "Izbrane datoteke ni mogoče prebrati.",
    "The file was uploaded" : "Datoteka je bila poslana.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega največjo dovoljeno velikosti, kot je zabeležena v datoteki php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki je določena kot omejitev MAX_FILE_SIZE v zapisu HTML.",
    "The file was only partially uploaded" : "Datoteka ni bila poslana v celoti",
    "No file was uploaded" : "Nobena datoteka ni bila poslana.",
    "Missing a temporary folder" : "Začasna mapa ni na voljo",
    "Could not write file to disk" : "Datoteke ni mogoče zapisati na disk",
    "A PHP extension stopped the file upload" : "Razširitev PHP onemogoča pošiljanje datoteke",
    "Invalid file provided" : "Predložena je neveljavna datoteka",
    "No image or file provided" : "Ni podane datoteke ali slike",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "An error occurred. Please contact your admin." : "Prišlo je do napake. Stopite v stik s skrbnikom sistema.",
    "Invalid image" : "Neveljavna slika",
    "State token does not match" : "Žeton stanja ni skladen",
    "Invalid app password" : "Neveljavno geslo programa",
    "Could not complete login" : "Prijave ni mogoče dokončati",
    "State token missing" : "Manjka žeton stanja",
    "Your login token is invalid or has expired" : "Prijavni žeton je neveljaven, ali pa je že potekel.",
    "Please use original client" : "Uporabite izvirnega odjemalca",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Ta skupnostna objava oblaka Nextcloud ni podprta, nekatera potisna obvestila so zato omejena.",
    "Login" : "Prijava",
    "Unsupported email length (>255)" : "Nepodprta dolžina sporočila ( > 255 )",
    "Password reset is disabled" : "Ponastavitev gesla je onemogočena",
    "Could not reset password because the token is expired" : "Ni mogoče ponastaviti gesla, ker je žeton pretekel.",
    "Could not reset password because the token is invalid" : "Ni mogoče ponastaviti gesla, ker žeton ni veljaven.",
    "Password is too long. Maximum allowed length is 469 characters." : "Geslo je predolgo. Geslo je lahko dolgo največ 469 znakov.",
    "%s password reset" : "Ponastavitev gesla %s",
    "Password reset" : "Ponastavitev gesla",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Za ponastavitev gesla kliknite na gumb. Če ponastavitve gesla niste zahtevali, prezrite to sporočilo.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Za ponastavitev gesla kliknite na povezavo. Če ponastavitve gesla niste zahtevali, prezrite to sporočilo.",
    "Reset your password" : "Ponastavi geslo",
    "The given provider is not available" : "Podan ponudnik ni na voljo",
    "Task not found" : "Naloge ni mogoče najti",
    "Internal error" : "Notranja napaka",
    "Not found" : "Predmeta ni mogoče najti",
    "Node is locked" : "Vozlišče je zaklenjeno",
    "Bad request" : "Neustrezna zahteva",
    "Requested task type does not exist" : "Zahtevana vrsta naloge ne obstaja",
    "Necessary language model provider is not available" : "Zahtevan ponudnik jezikovnega modela ni na voljo",
    "No text to image provider is available" : "Pretvornik besedila v sliko ni na voljo.",
    "Image not found" : "Slike ni mogoče najti",
    "No translation provider available" : "Ponudnik prevoda ni na voljo.",
    "Could not detect language" : "Ni mogoče zaznati jezika.",
    "Unable to translate" : "Ni mogoče prevajati",
    "No valid filters provided" : "Ni veljavnih filtrov",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Korak nadgradnje:",
    "Repair info:" : "Podrobnosti nadgradnje:",
    "Repair warning:" : "Opozorilo nadgradnje:",
    "Repair error:" : "Napaka nadgradnje:",
    "Nextcloud Server" : "Strežnik Nextcloud",
    "Some of your link shares have been removed" : "Nekatere povezave za souporabo so bile odstranjene.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zaradi varnostnih razlogov so bile nekatere povezave odstranjene. Več podrobnosti je na voljo v uradno izdanem opozorilu.",
    "The account limit of this instance is reached." : "Dosežena je omejitev računa za to nastavitev. ",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Vpišite ključ naročila podpornega programa in povečajte omejitev za uporabnika. S tem pridobite tudi vse dodatne ugodnosti, ki jih omogoča Poslovno okolje Nextcloud. Način je zelo priporočljiv za podjetja.",
    "Learn more ↗" : "Več o tem ↗",
    "Preparing update" : "Poteka priprava na posodobitev ...",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Posodobitev sistema je treba izvesti v ukazni vrstici, ker je posodabljanje z brskalnikom v config.php onemogočeno.",
    "Turned on maintenance mode" : "Vzdrževalni način je omogočen ...",
    "Turned off maintenance mode" : "Vzdrževalni način je onemogočen.",
    "Maintenance mode is kept active" : "Vzdrževalni način ostane dejaven.",
    "Updating database schema" : "Poteka posodabljanje sheme podatkovne zbirke ...",
    "Updated database" : "Podatkovna zbirka je posodobljena.",
    "Update app \"%s\" from App Store" : "Posodobi program »%s« iz trgovine.",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke za %s mogoče posodobiti (trajanje posodobitve je odvisno od velikosti zbirke).",
    "Updated \"%1$s\" to %2$s" : "Posodabljanje »%1$s« na različico %2$s",
    "Set log level to debug" : "Nastavljanje ravni beleženja za razhroščevanje",
    "Reset log level" : "Ponastavljanje ravni beleženja",
    "Starting code integrity check" : "Poteka preverjanje stanja kode ...",
    "Finished code integrity check" : "Preverjanje stanja kode je končano.",
    "%s (incompatible)" : "%s (neskladno)",
    "The following apps have been disabled: %s" : "Zaradi neskladnosti so onemogočeni naslednji programi: %s.",
    "Already up to date" : "Sistem je že posodobljen",
    "Windows Command Script" : "Ukazni skript Windows",
    "Electronic book document" : "Dokument elektronske knjige",
    "TrueType Font Collection" : "Zbirka pisav TTF",
    "Web Open Font Format" : "Odprti zapis spletne pisave",
    "GPX geographic data" : "Geografski podatki GPX",
    "Gzip archive" : "Arhiv GZIP",
    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
    "Java source code" : "Izvorna koda Java",
    "JavaScript source code" : "Izvorna koda Javascript",
    "JSON document" : "Dokument JSON",
    "Microsoft Access database" : "Podatkovna zbirka Microsoft Access",
    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
    "Microsoft Word document" : "Dokument Microsoft Word",
    "Unknown" : "Neznano",
    "PDF document" : "Dokument PDF",
    "PostScript document" : "Dokument PostScript",
    "RSS summary" : "Povzetek virov RSS",
    "Android package" : "Programski paket Android",
    "KML geographic data" : "Geografski podatki KLM",
    "KML geographic compressed data" : "Stisnjeni geografski podatki KLM",
    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
    "Excel spreadsheet" : "Preglednica Excel",
    "Excel add-in" : "Razširitev Excel",
    "Excel 2007 binary spreadsheet" : "Preglednica Excel 2007",
    "Excel spreadsheet template" : "Predloga preglednice Excel",
    "Outlook Message" : "Sporočilo Outlook",
    "PowerPoint presentation" : "Predstavitev PowerPoint",
    "PowerPoint add-in" : "Razširitev PowerPoint",
    "PowerPoint presentation template" : "Predloga predstavitve PowerPoint",
    "Word document" : "Dokument Word",
    "ODF formula" : "Formula ODF",
    "ODG drawing" : "Risba ODG",
    "ODG drawing (Flat XML)" : "Risba ODG (Flat XML)",
    "ODG template" : "Predloga ODG",
    "ODP presentation" : "Predstavitev ODP",
    "ODP presentation (Flat XML)" : "Predstavitev ODP (Flat XML)",
    "ODP template" : "Predloga ODP",
    "ODS spreadsheet" : "Preglednica ODS",
    "ODS spreadsheet (Flat XML)" : "Predstavitev ODS (Flat XML)",
    "ODS template" : "Predloga ODS",
    "ODT document" : "Dokument ODT",
    "ODT document (Flat XML)" : "Dokument ODT (Flat XML)",
    "ODT template" : "Predloga ODT",
    "PowerPoint 2007 presentation" : "Predstavitev PowerPoint 2007",
    "PowerPoint 2007 show" : "Predstavitev PowerPoint 2007",
    "PowerPoint 2007 presentation template" : "Predloga predstavitve PowerPoint 2007",
    "Excel 2007 spreadsheet" : "Preglednica Excel 2007",
    "Excel 2007 spreadsheet template" : "Predloga preglednice Excel 2007",
    "Word 2007 document" : "Dokument Word 2007",
    "Word 2007 document template" : "Predloga dokumenta Word 2007",
    "Microsoft Visio document" : "Dokument Microsoft Visio",
    "WordPerfect document" : "Dokument WordPerfect",
    "7-zip archive" : "Arhiv 7-zip",
    "Blender scene" : "Scena programa Blender",
    "Bzip2 archive" : "Arhiv Bzip2",
    "Debian package" : "Programski paket Debian",
    "FictionBook document" : "Dokument FictionBook",
    "Unknown font" : "Neznan zapis pisave",
    "Krita document" : "Dokument Krita",
    "Mobipocket e-book" : "Elektronska knjiga Mobipocket",
    "Windows Installer package" : "Namestitveni paket Windows",
    "Perl script" : "Skript Perl",
    "PHP script" : "Skript PHP",
    "Tar archive" : "Arhiv Tar",
    "XML document" : "Dokument XML",
    "YAML document" : "Dokument YAML",
    "Zip archive" : "Arhiv ZIP",
    "Zstandard archive" : "Arhiv Zstandard",
    "AAC audio" : "Zvok AAC",
    "FLAC audio" : "Zvok FLAC",
    "MPEG-4 audio" : "Zvok MPEG-4",
    "MP3 audio" : "Zvok MP3",
    "Ogg audio" : "Zvok OGG",
    "RIFF/WAVe standard Audio" : "Zvočni zapis RIFF/WAVe",
    "WebM audio" : "Zvok WebM",
    "Windows BMP image" : "Slika Windows BMP",
    "EMF image" : "Slika EMF",
    "GIF image" : "Slika GIF",
    "HEIC image" : "Slika HEIC",
    "HEIF image" : "Slika HEIF",
    "JPEG-2000 JP2 image" : "Slika JPEG-2000 JP2",
    "JPEG image" : "Slika JPEG",
    "PNG image" : "Slika PNG",
    "SVG image" : "Risba SVG",
    "Truevision Targa image" : "Slika Truevision Targa",
    "TIFF image" : "Slika TIFF",
    "WebP image" : "Slika WebP",
    "Digital raw image" : "Surova digitalna slika",
    "Windows Icon" : "Ikona Windows",
    "Email message" : "Elektronsko sporočilo",
    "VCS/ICS calendar" : "Koledar VCS/ICS",
    "CSS stylesheet" : "Slogovna predloga CSS",
    "CSV document" : "Dokument CSV",
    "HTML document" : "Dokument HTML",
    "Markdown document" : "Dokument Markdown",
    "Plain text document" : "Besedilni dokument",
    "Rich Text document" : "Dokument z obogatenim besedilom",
    "Electronic business card" : "Elektronska poslovna kartica",
    "C++ source code" : "Izvorna koda C++",
    "LDIF address book" : "Imenik LDIF",
    "NFO document" : "Dokument NFO",
    "PHP source" : "Izvorna koda PHP",
    "Python script" : "Skript Python",
    "3GPP multimedia file" : "Predstavna datoteka 3GPP",
    "MPEG video" : "Video MPEG",
    "DV video" : "Video DV",
    "MPEG-4 video" : "Video MPEG-4",
    "Ogg video" : "Video OGG",
    "QuickTime video" : "Video QuickTime",
    "WebM video" : "Video WebM",
    "Matroska video" : "Video Matroska",
    "Windows Media video" : "Video Windows Media",
    "AVI video" : "Video AVI",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "V teku je posodobitev. Odhod s te strani lahko v določenih okoljih prekine opravilo.",
    "Update to {version}" : "Posodobitev na različico {version}",
    "An error occurred." : "Prišlo je do napake.",
    "Please reload the page." : "Stran je treba osvežiti.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Posodobitev je spodletela. Več podrobnosti o napaki je <a href=\"{url}\">objavljenih na forumu</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Posodobitev je spodletela. Pošljite poročilo o napaki <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">skupnosti Nextcloud</a>.",
    "Continue to {productName}" : "Nadaljuj v {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundo.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundi.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekunde.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekund."],
    "Done" : "Končano",
    "Applications menu" : "Meni programov",
    "Apps" : "Programi",
    "More apps" : "Več programov",
    "_{count} notification_::_{count} notifications_" : ["{count} obvestilo","{count} obvestili","{count} obvestila","{count} obvestil"],
    "No" : "Ne",
    "Yes" : "Da",
    "App password" : "Geslo programa",
    "Grant access" : "Odobri dostop",
    "The remote URL must include the user." : "Oddaljeni naslov URL mora vključevati uporabniško ime.",
    "Invalid remote URL." : "Neveljaven oddaljeni naslov URL.",
    "Failed to add the public link to your Nextcloud" : "Dodajanje javne povezave v oblak je spodletelo.",
    "Federated user" : "Zvezni uporabnik",
    "user@your-nextcloud.org" : "uporabnik@oblak-nextcloud.org",
    "Create share" : "Ustvari predmet souporabe",
    "Please copy the link manually:" : "Povezave je treba kopirati ročno.",
    "Custom date range" : "Obseg datuma po meri",
    "Pick start date" : "Izbor začetnega datuma",
    "Pick end date" : "Izbori končnega datuma",
    "Search in date range" : "Išči v časovnem obdobju",
    "Search in current app" : "Poišči v predlaganem programu",
    "Clear search" : "Počisti iskanje",
    "Search everywhere" : "Išči povsod",
    "Searching …" : "Poteka iskanje ...",
    "Start typing to search" : "Začnite tipkati za iskanje",
    "No matching results" : "Ni zadetkov iskanja",
    "Today" : "Danes",
    "Last 7 days" : "Zadnjih 7 dni",
    "Last 30 days" : "Zadnjih 30 dni",
    "This year" : "Letos",
    "Last year" : "Lansko leto",
    "Unified search" : "Enoviti iskalnik",
    "Search apps, files, tags, messages" : "Iskanje programov, datotek, nalog in sporočil",
    "Places" : "Mesta",
    "Date" : "Datum",
    "Search people" : "Iskanje oseb",
    "People" : "Osebe",
    "Filter in current view" : "Filtrirajte trenutni pogled",
    "Results" : "Zadetki",
    "Load more results" : "Naloži več zadetkov",
    "Search in" : "Poišči v",
    "Log in" : "Prijava",
    "Log in to {productName}" : "Prijava v {productName}",
    "Wrong login or password." : "Napačna prijava ali geslo.",
    "This account is disabled" : "Ta račun je onemogočen",
    "Account name or email" : "Ime računa ali elektronski naslov",
    "Account name" : "Ime računa",
    "Server side authentication failed!" : "Overitev na strani strežnika je spodletela!",
    "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
    "Session error" : "Napaka seje",
    "It appears your session token has expired, please refresh the page and try again." : "Žeton seje je verjetno potekel. Osvežite stran in poskusite znova.",
    "An internal error occurred." : "Prišlo je do notranje napake.",
    "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
    "Password" : "Geslo",
    "Log in with a device" : "Prijava z napravo",
    "Login or email" : "Prijavno ime ali elektronski naslov",
    "Your account is not setup for passwordless login." : "Račun ni nastavljen za brezgeselno prijavo.",
    "Your connection is not secure" : "Vzpostavljena povezava ni varna",
    "Passwordless authentication is only available over a secure connection." : "Brezgeselna overitev je na voljo le prek vzpostavljene varne povezave.",
    "Browser not supported" : "Trenutno uporabljen brskalnik ni podprt!",
    "Passwordless authentication is not supported in your browser." : "Brezgeselna overitev v tem brskalniku ni podprta.",
    "Reset password" : "Ponastavi geslo",
    "Back to login" : "Nazaj na prijavo",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Če račun obstaja, bo na elektronski naslov poslano sporočilo za ponastavitev gesla. Če ne prispe, preverite elektronski naslov, prijavne podatke, poglejte med neželeno pošte oziroma stopite v stik s skrbnikom sistema.",
    "Couldn't send reset email. Please contact your administrator." : "Ni mogoče poslati elektronskega sporočila za ponastavitev. Stopite v stik s skrbnikom sistema.",
    "Password cannot be changed. Please contact your administrator." : "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
    "New password" : "Novo geslo",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Datoteke so šifrirane. Če niste omogočili obnovitvenega ključa, po ponastavitvi gesla dostop do datotek ne bo več mogoč.<br />Če niste prepričani, kaj storiti, stopite v stik s skrbnikom sistema.<br />Ali res želite nadaljevati?",
    "I know what I'm doing" : "Vem, kaj delam!",
    "Resetting password" : "Ponastavljanje gesla",
    "Schedule work & meetings, synced with all your devices." : "Načrtujte delo in sestanke, ki se samodejno usklajujejo z vsemi vašimi napravami.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Združite sodelavce in prijatelje na enem mestu brez skrbi za njihove zasebne podatke.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enostaven program za pošto se odlično povezuje z Datotekami, Stiki in Koledarjem.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Klepet, videopogovori, souporaba zaslona, spletni sestanki in spletne konference – v spletnem brskalniku ali na mobilnih napravah.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Sodelovanje pri ustvarjanju dokumentov, preglednic in predstavitev, ki zahtevajo storitev Collabora Online.",
    "Distraction free note taking app." : "Enostavno beleženje in zapisovanje",
    "Recommended apps" : "Priporočeni programi",
    "Loading apps …" : "Poteka nalaganje programov ...",
    "Could not fetch list of apps from the App Store." : "Ni mogoče pridobiti seznama programov iz trgovine.",
    "App download or installation failed" : "Prejem oziroma namestitev programa je spodletela.",
    "Cannot install this app because it is not compatible" : "Programa ni mogoče namestiti, ker ni skladen z različico okolja.",
    "Cannot install this app" : "Programa ni mogoče namestiti.",
    "Skip" : "Preskoči",
    "Installing apps …" : "Poteka nameščanje programov ...",
    "Install recommended apps" : "Namesti priporočene programe",
    "Online" : "Trenutno na spletu",
    "Away" : "Ne spremljam",
    "Busy" : "Zasedeno",
    "Do not disturb" : "Ne moti",
    "Mute all notifications" : "Utiša vsa obvestila",
    "Invisible" : "Drugim nevidno",
    "Appear offline" : "Pokaže kot brez povezave",
    "Avatar of {displayName}" : "Podoba osebe {displayName}",
    "Settings menu" : "Meni nastavitev",
    "Search contacts" : "Poišči med stiki",
    "Reset search" : "Ponastavi iskanje",
    "Could not load your contacts" : "Stikov ni mogoče naložiti",
    "No contacts found" : "Ni najdenih stikov",
    "Show all contacts" : "Prikaži vse stike",
    "Install the Contacts app" : "Namesti program Stiki",
    "Search" : "Poišči",
    "No results for {query}" : "Ni zadetkov za poizvedbo {query}",
    "Press Enter to start searching" : "Pritisnite vnosnico za začetek iskanja",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Vpisati je treba vsaj {minSearchLength} znak za začetek iskanja","Vpisati je treba vsaj {minSearchLength} znaka za začetek iskanja","Vpisati je treba vsaj {minSearchLength} znake za začetek iskanja","Vpisati je treba vsaj {minSearchLength} znakov za začetek iskanja"],
    "An error occurred while searching for {type}" : "Prišlo je do napake med iskanjem vrste {type}.",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Iskanje se začne, ko začnete vpisovati besedilo, do rezultatov pa je mogoče dostop tudi s smernimi tipkami.",
    "Search for {name} only" : "Išči le za {name}",
    "Forgot password?" : "Ali ste pozabili geslo?",
    "Back to login form" : "Nazaj na prijavni obrazec",
    "Back" : "Nazaj",
    "Login form is disabled." : "Prijavni obrazec je onemogočen.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prijavni obrazec Nextcloud je onemogočen. Če je mogoče, izberite drug način prijave, ali pa stopite v stik s skrbnikom sistema.",
    "Connect to your account" : "Povežite z računom",
    "Security warning" : "Varnostno opozorilo",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Če ne poskušate dodati naprave ali programa, vas poskuša nekdo pretentati v odobritev dostopa do vaših podatkov. Če se vam zdi, da je tako, ne nadaljujte s potrjevanjem, ampak stopite v stik s skrbnikom sistema.",
    "Alternative log in using app password" : "Alternativni način prijave z uporabo gesla programa",
    "Account connected" : "Račun je povezan",
    "Your client should now be connected!" : "Odjemalec naj bi bil sedaj povezan!",
    "You can close this window." : "To okno lahko zaprete.",
    "Account access" : "Dostop do računa",
    "More actions" : "Več dejanj",
    "User menu" : "Uporabniški meni",
    "Set public name" : "Nastavi javno ime",
    "Change public name" : "Spremeni javno ime",
    "This share is password-protected" : "To mesto je zaščiteno z geslom",
    "The password is wrong or expired. Please try again or request a new one." : "Geslo je napačno ali je preteklo. Poskusite znova ali zahtevajte novo geslo.",
    "Submit" : "Pošlji",
    "Please type in your email address to request a temporary password" : "Vpišite elektronski naslov, na katerega bo začasno dodeljeno gesla.",
    "Password sent!" : "Geslo je poslano!",
    "You are not authorized to request a password for this share" : "Za zahteve pridobitve gesla ni ustreznih dovoljenj",
    "Email address" : "Elektronski naslov",
    "Request password" : "Zahtevaj geslo",
    "Forgot password" : "Ali ste pozabili geslo?",
    "Password is too weak" : "Geslo je prešibko",
    "Password is weak" : "Geslo je šibko",
    "Password is average" : "Geslo je povprečno",
    "Password is strong" : "Geslo je močno",
    "Password is very strong" : "Geslo je zelo močno",
    "Password is extremely strong" : "Geslo je izjemno močno",
    "Unknown password strength" : "Neznana moč gesla",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Podatkovni imenik in datoteke so verjetno dostopne s spleta, ker datoteka <code>.htaccess</code> ne deluje.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Za podrobnosti o pravilnih nastavitvah strežnika {linkStart}preglejte dokumentacijo{linkEnd}",
    "Autoconfig file detected" : "Zaznana je datoteka za samodejno nastavitev",
    "The setup form below is pre-filled with the values from the config file." : "Namestitveni obrazec je izpolnjen iz vrednostmi, prevzetimi iz nastavitvene datoteke.",
    "Create administration account" : "Ustvari skrbniški račun",
    "Administration account name" : "Ime skrbniškega računa",
    "Administration account password" : "Geslo skrbniškega računa",
    "Storage & database" : "Shramba in podatkovna zbirka",
    "Data folder" : "Podatkovna mapa",
    "Database configuration" : "Nastavitve podatkovne zbirke",
    "Database type" : "Vrsta podatkovne zbirke",
    "Only {firstAndOnlyDatabase} is available." : "Na voljo je le {firstAndOnlyDatabase}",
    "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
    "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
    "Performance warning" : "Opozorilo učinkovitosti delovanja",
    "You chose SQLite as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Podatkovna zbirka SQLite je primerna le za manjše in razvojne namestitve. Za produkcijsko okolje je priporočljivo uporabiti drugo podatkovno ozadje.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Če uporabljate namizni odjemalec za usklajevanje datotek, je uporaba podatkovne zbirke SQLite odsvetovana.",
    "Database user" : "Uporabnik podatkovne zbirke",
    "Database password" : "Geslo podatkovne zbirke",
    "Database name" : "Ime podatkovne zbirke",
    "Database tablespace" : "Razpredelnica podatkovne zbirke",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Skupaj z imenom gostitelja je treba določiti tudi številko vrat (na primer localhost:5432).",
    "Database host" : "Gostitelj podatkovne zbirke",
    "localhost" : "localhost",
    "Installing …" : "Poteka nameščanje ...",
    "Install" : "Namesti",
    "Need help?" : "Ali potrebujete pomoč?",
    "See the documentation" : "Preverite dokumentacijo",
    "{name} version {version} and above" : "{name} različica {version} ali višja",
    "This browser is not supported" : "Trenutno uporabljen brskalnik ni podprt!",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Uporabljen brskalnik ni podprt. Posodobite program na novejšo različico, ali pa uporabite drug program.",
    "Continue with this unsupported browser" : "Nadaljuj delo z nepodprtim brskalnikom",
    "Supported versions" : "Podprte različice",
    "Choose {file}" : "Izberite datoteko {file}",
    "Choose" : "Izbor",
    "Copy to {target}" : "Kopiraj na {target}",
    "Copy" : "Kopiraj",
    "Move to {target}" : "Premakni na {target}",
    "Move" : "Premakni",
    "OK" : "V redu",
    "read-only" : "le za branje",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} spor datotek","{count} spora datotek","{count} spori datotek","{count} sporov datotek"],
    "One file conflict" : "En spor datotek",
    "New Files" : "Nove datoteke",
    "Already existing files" : "Obstoječe datoteke",
    "Which files do you want to keep?" : "Katere datoteke želite ohraniti?",
    "If you select both versions, the copied file will have a number added to its name." : "Če izberete obe različici, bo k imenu kopirane datoteke dodana številka.",
    "Cancel" : "Prekliči",
    "Continue" : "Nadaljuj",
    "(all selected)" : "(vse izbrano)",
    "({count} selected)" : "({count} izbranih)",
    "Error loading file exists template" : "Napaka nalaganja predloge obstoječih datotek",
    "Saving …" : "Poteka shranjevanje …",
    "Groups" : "Skupine",
    "Group list is empty" : "Seznam skupin je prazen",
    "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
    "seconds ago" : "pred nekaj sekundami",
    "Connection to server lost" : "Povezava s strežnikom je izgubljena",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundo.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundi.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekunde.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekund."],
    "Add to a project" : "Dodaj k projektu",
    "Show details" : "Pokaži podrobnosti",
    "Hide details" : "Skrij podrobnosti",
    "Rename project" : "Preimenuj projekt",
    "Failed to rename the project" : "Preimenovanje projekta je spodletelo.",
    "Failed to create a project" : "Ustvarjanje projekta je spodletelo",
    "Failed to add the item to the project" : "Dodajanje predmeta k projektu je spodletelo.",
    "Connect items to a project to make them easier to find" : "Povežite predmete s projektom, da jih bo lažje najti.",
    "Type to search for existing projects" : "Vpišite niz za iskanje obstoječih projektov",
    "New in" : "Novo v",
    "View changelog" : "Poglej dnevnik sprememb",
    "Close \"{dialogTitle}\" dialog" : "Zapri pogovorno okno »{dialogTitle}«",
    "Email length is at max (255)" : "Dolžina sporočila je dosegla omejitev (255)",
    "Clipboard not available, please copy manually" : "Odložišče ni na voljo, kopirajte ročno",
    "Personal" : "Osebno",
    "Accounts" : "Računi",
    "Admin" : "Skrbništvo",
    "Help" : "Pomoč",
    "Access forbidden" : "Dostop je prepovedan",
    "Back to %s" : "Nazaj na %s",
    "Page not found" : "Strani ni mogoče najti",
    "The page could not be found on the server or you may not be allowed to view it." : "Strani na strežniku ni mogoče najti ali pa ni ustreznih dovoljenj za prikaz.",
    "Too many requests" : "Zaznanih je preveč sočasnih zahtev",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iz omrežja je bilo prejetih preveč zahtev. Če je to napaka, stopite v stik s skrbnikom, sicer pa poskusite spet kasneje.",
    "Error" : "Napaka",
    "Internal Server Error" : "Notranja napaka strežnika",
    "The server was unable to complete your request." : "Odziv strežnika kaže, da zahteve ni mogoče dokončati.",
    "If this happens again, please send the technical details below to the server administrator." : "Če se napaka ponovi, pošljite tehnične podrobnosti, ki so zbrane spodaj, skrbniku sistema.",
    "More details can be found in the server log." : "Več podrobnosti je zabeleženih v dnevniški datoteki strežnika.",
    "For more details see the documentation ↗." : "Za več podrobnosti preverite dokumentacijo Nova opomba ….",
    "Technical details" : "Tehnične podrobnosti",
    "Remote Address: %s" : "Oddaljen naslov: %s",
    "Request ID: %s" : "ID zahteve: %s",
    "Type: %s" : "Vrsta: %s",
    "Code: %s" : "Koda: %s",
    "Message: %s" : "Sporočilo: %s",
    "File: %s" : "Datoteka: %s",
    "Line: %s" : "Vrstica: %s",
    "Trace" : "Sledenje povezav",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Kaže, da poskušate ponovno namestiti okolje Nextcloud, a datoteke CAN_INSTALL ni v mapi nastavitev. Ustvarite jo, potem lahko poskusite znova.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ni mogoče odstraniti datoteke CAN_INSTALL iz nastavitvene mape. Odstranite jo ročno.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
    "Skip to main content" : "Preskoči na glavno vsebino",
    "Skip to navigation of app" : "Preskoči na program za krmarjenje",
    "Go to %s" : "Odpri oblak %s",
    "Get your own free account" : "Pridobite brezplačni račun",
    "Previous" : "Predhodna",
    "Two-factor authentication" : "Dvo-stopenjska overitev",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Za vaš račun je omogočena zahteva za višjo raven varnosti. Izberite drugo stopnjo overitve:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ni mogoče naložiti niti enega od omogočenih načinov dvostopenjske overitve prijave. Stopite v stik s skrbnikom sistema.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Zahtevana je uporaba dvostopenjske overitve prijave, a za ta račun še ni nastavljena. Stopite v stik s skrbnikom sistema.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Zahtevana je uporaba dvostopenjske overitve prijave, a za ta račun še ni nastavljena. Nadaljujte s postopkom priprave overitve.",
    "Set up two-factor authentication" : "Nastavitev dvostopenjske overitve",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Zahtevana je uporaba dvostopenjske overitve prijave, a za ta račun še ni nastavljena. Za prijavo uporabite eno izmed varnostnih kod, ali pa za pomoč stopite v stik s skrbnikom sistema.",
    "Use backup code" : "Uporabi varnostno kopijo šifre",
    "Cancel login" : "Prekliči prijavo",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Za vaš račun je vsiljena zahteva za višjo raven varnosti. Izberite ponudnika za nastavitev:",
    "Error while validating your second factor" : "Napaka med preverjanjem drugega koraka",
    "Access through untrusted domain" : "Dostop z uporabo domene, ki ni zaupanja vredna",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Stopite v stik s skrbnikom sistema. Če ste skrbnik, prilagodite nastavitev »trusted_domains« v datoteki config/config.php, kot je zavedeno v predlogi config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Podrobnosti o možnostih nastavitev je mogoče najti v %1$sdokumentaciji%2$s.",
    "App update required" : "Zahtevana je posodobitev programa",
    "%1$s will be updated to version %2$s" : "Okolje %1$s bo posodobljeno na različico %2$s",
    "The following apps will be updated:" : "Navedeni programi bodo posodobljeni:",
    "These incompatible apps will be disabled:" : "Zaradi neskladnosti bodo onemogočeni:",
    "The theme %s has been disabled." : "Tema %s je onemogočena za uporabo.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred nadaljevanjem se prepričajte, da je ustvarjena varnostna kopija podatkovne zbirke, nastavitvenih datotek in podatkovne mape.",
    "Start update" : "Začni posodobitev",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
    "Detailed logs" : "Podrobni dnevniški zapisi",
    "Update needed" : "Zahtevana je posodobitev",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Uporabite posodabljalnik ukazne vrstice, ker je v sistemu več kot 50 računov.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Za pomoč si oglejte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentacijo</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Zavedam se, da obstaja pri posodabljanju prek spletnega uporabniškega vmesnika nevarnost, da zahteva časovno poteče in s tem povzroči izgubo podatkov. Imam ustvarjeno varnostno kopijo in znam podatke iz kopij v primeru napak obnoviti.",
    "Upgrade via web on my own risk" : "Posodobi prek spleta kljub večjemu tveganju",
    "Maintenance mode" : "Vzdrževalni način",
    "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v vzdrževalnem načinu, kar onemogoča prijavo.",
    "This page will refresh itself when the instance is available again." : "Stran bo samodejno osvežena, ko bo okolje spet pripravljeno za delo.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Če se bo to sporočilo še naprej nepričakovano pojavljalo, stopite v stik s skrbnikom sistema.",
    "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Za več podrobnosti preverite {linkstart}dokumentacijo ↗{linkend}.",
    "unknown text" : "neznano besedilo",
    "Hello world!" : "Pozdravljen svet!",
    "sunny" : "sončno",
    "Hello {name}, the weather is {weather}" : "Pozdravljeni, {name}, vreme je {weather}",
    "Hello {name}" : "Pozdravljeni, {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To so zadetki iskanja<script>alert(1)</script></strong>.",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["prejmi %n datoteko","prejmi %n datoteki","prejmi %n datoteke","prejmi %n datotek"],
    "Direct link copied to clipboard" : "Povezava je kopirana v odložišče.",
    "Searching …" : "Poteka iskanje ...",
    "Logging in …" : "Poteka prijavljanje ...",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznanih je več neveljavnih poskusov prijave iz trenutnega naslova IP. Iz varnostnih razlogov bo možnost naslednjega poskusa prijave zadržana za 30 sekund.",
    "Loading apps …" : "Poteka nalaganje programov ...",
    "Installing apps …" : "Poteka nameščanje programov ...",
    "Loading your contacts …" : "Poteka nalaganje stikov ...",
    "Looking for {term} …" : "Poteka iskanje {term} …",
    "Search contacts …" : "Poišči med stiki ...",
    "Loading more results …" : "Poteka nalaganje več zadetkov ...",
    "Search {types} …" : "Poišči {types} …",
    "Saving …" : "Poteka shranjevanje ...",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Šibko geslo",
    "So-so password" : "Slabo geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "No action available" : "Ni razpoložljivih dejanj",
    "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
    "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
    "Restricted" : "Omejeno",
    "Delete" : "Izbriši",
    "Rename" : "Preimenuj",
    "Collaborative tags" : "Sodelovalne oznake",
    "No tags found" : "Ni najdenih oznak",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni v omrežju, ker datoteka .htaccess ni ustrezno nastavljena.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Več podrobnosti, kako pravilno nastaviti strežnik, je zapisanih v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Ustvari skrbniški račun</strong>",
    "New admin account name" : "Ime novega skrbniškega računa",
    "New admin password" : "Geslo novega skrbniškega računa",
    "Show password" : "Pokaži geslo",
    "Toggle password visibility" : "Preklopi vidnost gesla",
    "Configure the database" : "Nastavi podatkovno zbirko",
    "Only %s is available." : "Na voljo je le %s.",
    "Database account" : "Račun podatkovne zbirke",
    "Installing …" : "Poteka nameščanje ...",
    "Please log in before granting %1$s access to your %2$s account." : "Pred %1$s odobritvijo dostopa %2$s do računa se je treba prijaviti.",
    "Currently logged in as %1$s (%2$s)." : "Dejavna je prijava %1$s (%2$s)",
    "You are about to grant %1$s access to your %2$s account." : "Računu %1$s boste omogočili dostop do vašega računa %2$s."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
